scoretools.Performer
====================

.. abjad-lineage:: abjad.tools.scoretools.Performer.Performer.Performer

.. autoclass:: abjad.tools.scoretools.Performer.Performer.Performer
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.scoretools.Performer.Performer.Performer.instrument_count
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Performer.Performer.Performer.is_doubling
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Performer.Performer.Performer.likely_instruments_based_on_performer_name
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Performer.Performer.Performer.most_likely_instrument_based_on_performer_name
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Performer.Performer.Performer.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.scoretools.Performer.Performer.Performer.instruments
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Performer.Performer.Performer.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.make_performer_name_instrument_dictionary
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__ge__
   :noindex:

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__gt__
   :noindex:

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__hash__
   :noindex:

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__le__
   :noindex:

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__lt__
   :noindex:

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__repr__
   :noindex:
